@@ -137,6 +137,10 @@ void  messanykey(int x1,int y1,char* txtstr)
    scrcolor(fcolor_tmp,bcolor_tmp);
 }
 
+void messanykeyErr(int x1,int y1,char* txtstr)
+{ if(blind) { fprintf(stderr,"%s\n",txtstr); exit(33);}  
+  else messanykey(x1,y1,txtstr); 
+}
 
 
 int infoLine(double rate)
