@@ -146,7 +146,7 @@ static void  drawgraph(void)
  double  f[202]; 
    
   calccoef();
-  if(err_code) { messanykey(10,10,"Error in kinematics"); return; }
+  if(err_code) { messanykeyErr(10,10,"Error in kinematics"); return; }
           
   do
   {  if (correctInt(56,8,"Number of points=",&n,1))
@@ -159,7 +159,7 @@ static void  drawgraph(void)
 
            
   if( !fillseq(n,f)) 
-  {  messanykey(10,10,"Error in calculation"); 
+  {  messanykeyErr(10,10,"Error in calculation for plot construction"); 
      return;
   }
 
