@@ -233,7 +233,7 @@ int correctHistList(void)
  errorExit:
    { char buff[300];
      sprintf(buff,"Histograms:  Error in  line %d .\n%s. %s",lineNum,fieldName,errorText); 
-     messanykey(2,10,buff);
+     messanykeyErr(2,10,buff);
    }  
    return 1;
 }
@@ -693,7 +693,7 @@ void showHist(int X, int Y,char *title)
          {  
             char xname[80],yname[80],units[80];                                    
                                                                                    
-            if( hist->nPoints == 0) messanykey(10,10,"Distibution is empty");     
+            if( hist->nPoints == 0) messanykeyErr(10,10,"Distribution is empty");     
             else
             if(strcmp(hist->key[1],"0")==0)
             while((nBin1=nBinMenu(X,Y+4)))                                                                   
