@@ -202,7 +202,7 @@ static void f7_prog(int mode)
               plot_N(title,xName,z1,z2,  LOG,1, nPoints, f[l],NULL,p_name[l]);   
            }  
            put_text(&screen);
-         } else messanykey(16,5," Correct input is \n"
+         } else messanykeyErr(16,5," Correct input is \n"
                                 "  0<=xMin<xMax<=1,\n"
                                 " 3<=nPoints<=150");
         }                        
@@ -269,7 +269,7 @@ static int  in_setting(void)
          else pinf_int(Nsub,i+1,mass+i,NULL);         
 
          if((mass[0]==0 && inP1<=0)|| (mass[1]==0 && inP2<=0)) 
-           messanykey(10,10,"For massless particle\nmomentum should be positive\n");
+           messanykeyErr(10,10,"For massless particle\nmomentum should be positive\n");
          else 
          {
            initStrFun(0);                                                                                                    
@@ -293,7 +293,7 @@ static int  in_setting(void)
                   sprintf(txt, "Enter new value [%.1f,%.1f] :", -(spin2/2.),(spin2/2.));
                   correctDouble(40,12,txt,&buf,1);
                   if(fabs(2*buf)>spin2) 
-                  { messanykey( 10,10,"Helicity out of limits");
+                  { messanykeyErr( 10,10,"Helicity out of limits");
                     if(blind) exit(111);
                   }else 
                   { Helicity[0]=buf;
@@ -308,7 +308,7 @@ static int  in_setting(void)
                   sprintf(txt, "Enter new value [%.1f,%.1f] :", -(spin2/2.),(spin2/2.));
                   correctDouble(40,12,txt,&buf,1);
                   if(fabs(2*buf)>spin2) 
-                  { messanykey( 10,10,"Helicity out of limits");
+                  { messanykeyErr( 10,10,"Helicity out of limits");
                     if(blind) exit(111);
                   }else 
                   { Helicity[1]=buf;
@@ -511,7 +511,7 @@ int monte_carlo_menu(void)
         case  10: 
                  if(nout_int==1 && !sf_num[0] && !sf_num[1]  ) 
                  { if(blind)  return 1;                     
-                   messanykey(15,15,"Phase space integration for 2->1 processes\n needs distribution functions.");
+                   messanykeyErr(15,15,"Phase space integration for 2->1 processes\n needs distribution functions.");
                    break;
                  }
                                                                         
@@ -560,13 +560,13 @@ int monte_carlo_menu(void)
                      return 1;
                    }
                             
-                   messanykey(15,15,"Energy is too small!");                   
+                   messanykeyErr(15,15,"Energy is too small!");                   
                    break;
                  }
 
                  if(fillCutArray()) 
                  { if(blind) return 2;
-                   messanykey(15,15,"Can not evaluate cut limits"); 
+                   messanykeyErr(15,15,"Can not evaluate cut limits"); 
                    break;
                  }  
         case 11:
