@@ -572,7 +572,7 @@ int runVegas(void)
            if( !veg_Ptr || !veg_Ptr->fMax)
            { char * mess="Before event generation one has to launch  Vegas session with freezed grid\n"
                                            "to prepare generator";
-                if(blind) { printf("%s\n",mess); sortie(200);}  else messanykey(4,13,mess);
+                messanykeyErr(4,13,mess);
            } else  runEvents();
        }
     }    
