@@ -17,7 +17,7 @@ int isCMathF(char*f)
    if(strcmp(f,"abs")==0) return 'N';
    sprintf(_f_," %s ",f);
    if(strstr(" + - * / ^ if ",_f_)) return 'b'; 
-   if(strstr(" sqrt pow  exp log log10 sin cos tan asin acos atan sinh cosh tanh asinh acosh atanh atan2 cimag creal carg cabs ",_f_)) return 'R';
+   if(strstr(" sqrt pow  exp log log10 sin cos tan asin acos atan sinh cosh tanh asinh acosh atanh atan2 fabs cimag creal carg cabs ",_f_)) return 'R';
    if(strstr(" conj cacos casin catan ccos csin ctan cacosh casinh catanh ccosh csinh ctanh cexp clog clog10 cpow csqrt  cproj ",_f_)) return 'C'; 
    return 0;
 }
