@@ -1432,11 +1432,15 @@ int makeVandP(int rd ,char*path,int L, int mode,char*CalcHEP)
     if(i+1>anti)  continue;
     if(nLn)fprintf(f,","); else fprintf(f," "); nLn++; 
       fprintf(f," {\"%s\",",prtclbase[i].name);
-      if(i+1==anti)   fprintf(f,"\"%s\", ",prtclbase[i].name);
-           else       fprintf(f,"\"%s\", ",prtclbase[anti-1].name);
-     fprintf(f,"%d, \"%s\",\"%s\",%d,%d,%d}\n",
+      if(i+1==anti)   fprintf(f,"\"%s\",1, ",prtclbase[i].name);
+           else       fprintf(f,"\"%s\",0, ",prtclbase[anti-1].name);
+     int dim1=prtclbase[i].spin+1; 
+     if(prtclbase[i].spin==1 && strchr("LR",prtclbase[i].hlp)) dim1=1;
+     if(prtclbase[i].spin==2 && strcmp("0",prtclbase[i].massidnt)==0) dim1=2;
+     dim1*=prtclbase[i].cdim;         
+     fprintf(f,"%d, \"%s\",\"%s\",%d,%d,%d,%d}\n",
        prtclbase[i].N,  prtclbase[i].massidnt, prtclbase[i].imassidnt,  
-       prtclbase[i].spin, prtclbase[i].cdim,prtclbase[i].q3);
+       prtclbase[i].spin, prtclbase[i].cdim,dim1,  prtclbase[i].q3);
     
   }
   fprintf(f,"};\n");
