@@ -9,7 +9,7 @@
 extern double alpha_2(double);
 #ifndef __cplusplus
 typedef REAL (DNN)(double, REAL *,REAL*,double*, int *);
-typedef REAL (FNN)(double,REAL*,REAL*,COMPLEX*,REAL*,REAL*);
+typedef REAL (FNN)(double, REAL*,REAL*,REAL*,COMPLEX*,REAL*,REAL*,int gsw,int gtw);
 #endif
 
 extern  REAL Helicity[2];
